# Instance schemas

The schemas in this directory represent the instance types, i.e. what the
model/block/link... payload will look like. These do not represent static
properties of the block classes, which are found in `block-class.schema.json`
and `blocks/...`.
